from urllib.parse import quote
from Crypto.Cipher import AES
from Crypto.Random import get_random_bytes
from Crypto.Util.Padding import pad
import json
import base64
from Crypto.Util.Padding import unpad






import setuptools


setuptools.setup(
    name="hbyvvv",
    version="1.0",
    author="hk",
    author_email="1301016428@qq.com.com",
    description="",
    long_description="spider tools",
    long_description_content_type="spider tools",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
